{book.title}
Author: {author}

!for author in book.authors: !for url in renderer.styles: !for url in renderer.scripts:
%!for n, chapter in enumerate(book.chapters, 1): %eval renderer.set_chapter({chapter.id!r})
%include: chapter.text load="chapter" with_namespace=True %append toc
- {renderer.current_chapter.title} !if renderer.current_chapter.sections:
  !for section_id, section in renderer.current_chapter.sections.items():
  - {section.title}